.. pycraf-mc:

*********************************
Monte-Carlo helpers (`pycraf.mc`)
*********************************

.. currentmodule:: pycraf.mc

Introduction
============

The `~pycraf.mc` subpackage


See Also
========

- `Kernel density estimation (KDE) <https://jakevdp.github.io/blog/2013/12/01/kernel-density-estimation/>`__, blog by Jake Vanderplas.
- `Scipy gaussian_kde <https://docs.scipy.org/doc/scipy-0.15.1/reference/generated/scipy.stats.gaussian_kde.html#scipy.stats.gaussian_kde>`__

Reference/API
=============

.. automodapi:: pycraf.mc
    :no-inheritance-diagram:
    :include-all-objects:
